@@ -25,9 +25,18 @@ public:
      * expireNever is used to switch off message expiry, and expireMaxUnits
      * must always be the last in the list (for bounds checking).
      */
-    enum ExpireUnits { ExpireNever = 0, ExpireDays = 1, ExpireWeeks = 2, ExpireMonths = 3, ExpireMaxUnits = 4 };
+    enum ExpireUnits {
+        ExpireNever = 0,
+        ExpireDays = 1,
+        ExpireWeeks = 2,
+        ExpireMonths = 3,
+        ExpireMaxUnits = 4,
+    };
 
-    enum ExpireAction { ExpireDelete = 0, ExpireMove = 1 };
+    enum ExpireAction {
+        ExpireDelete = 0,
+        ExpireMove = 1,
+    };
 
     [[nodiscard]] QByteArray type() const override;
     ExpireCollectionAttribute *clone() const override;
@@ -93,7 +102,7 @@ public:
     /**
      * If expiry should move to folder, return the ID of that folder
      */
-    Akonadi::Collection::Id expireToFolderId() const;
+    [[nodiscard]] Akonadi::Collection::Id expireToFolderId() const;
     void setExpireToFolderId(Akonadi::Collection::Id id);
 
     /**
@@ -108,7 +117,7 @@ public:
      */
     [[nodiscard]] ExpireUnits readExpireUnits() const;
 
-    bool operator==(const ExpireCollectionAttribute &other) const;
+    [[nodiscard]] bool operator==(const ExpireCollectionAttribute &other) const;
     [[nodiscard]] bool expireMessagesWithValidDate() const;
     void setExpireMessagesWithValidDate(bool expireMessagesWithValidDate);
 
