@@ -43,7 +43,7 @@ FilterAction::ReturnCode FilterActionAddHeader::process(ItemContext &context, bo
     if (!header) {
         header = new KMime::Headers::Generic(mParameter.toLatin1().constData());
     }
-    header->fromUnicodeString(mValue, "utf-8");
+    header->fromUnicodeString(mValue);
 
     msg->setHeader(header);
     msg->assemble();
@@ -73,7 +73,7 @@ QWidget *FilterActionAddHeader::createParamWidget(QWidget *parent) const
 
     layout->addWidget(comboBox, 0 /* stretch */);
 
-    auto label = new QLabel(i18n("With value:"), widget);
+    auto label = new QLabel(i18nc("@label:textbox", "With value:"), widget);
     label->setObjectName(QLatin1StringView("label_value"));
     label->setFixedWidth(label->sizeHint().width());
     layout->addWidget(label, 0);
