@@ -120,7 +120,7 @@ RedirectDialog::RedirectDialog(SendMode mode, QWidget *parent)
     auto mainLayout = new QVBoxLayout;
     mainWidget->setLayout(mainLayout);
     mainLayout->setContentsMargins({});
-    auto LabelTo = new QLabel(i18n("Select the recipient addresses to redirect to:"), this);
+    auto LabelTo = new QLabel(i18nc("@label:textbox", "Select the recipient addresses to redirect to:"), this);
     mainLayout->addWidget(LabelTo);
 
     auto formLayout = new QFormLayout;
@@ -155,8 +155,8 @@ RedirectDialog::RedirectDialog(SendMode mode, QWidget *parent)
     d->mTransportCombobox = new MailTransport::TransportComboBox;
     formLayout->addRow(i18n("Transport:"), d->mTransportCombobox);
 
-    KGuiItem::assign(d->mUser1Button, KGuiItem(i18n("&Send Now"), QIcon::fromTheme(QStringLiteral("mail-send"))));
-    KGuiItem::assign(d->mUser2Button, KGuiItem(i18n("Send &Later"), QIcon::fromTheme(QStringLiteral("mail-queue"))));
+    KGuiItem::assign(d->mUser1Button, KGuiItem(i18nc("@action:button", "&Send Now"), QIcon::fromTheme(QStringLiteral("mail-send"))));
+    KGuiItem::assign(d->mUser2Button, KGuiItem(i18nc("@action:button", "Send &Later"), QIcon::fromTheme(QStringLiteral("mail-queue"))));
     connect(d->mUser1Button, &QPushButton::clicked, this, [this]() {
         d->slotUser1();
     });
